@@ -49,7 +49,7 @@ public:
      * Resizes the items when the view is resized.
      * @param p_event the resize event
      */
-    void resizeEvent(QResizeEvent *p_event);
+    void resizeEvent(QResizeEvent *p_event) Q_DECL_OVERRIDE;
 
 protected:
 
@@ -57,13 +57,13 @@ protected:
      * Manages the player actions by hanlding the key press events.
      * @param p_event the key press event
      */
-    void keyPressEvent(QKeyEvent *p_event);
+    void keyPressEvent(QKeyEvent *p_event) Q_DECL_OVERRIDE;
 
     /**
      * Pauses the game on focus lost.
      * @param p_event the focus event
      */
-    void focusOutEvent(QFocusEvent *p_event);
+    void focusOutEvent(QFocusEvent *p_event) Q_DECL_OVERRIDE;
 
 signals:
 
